.. _spkg_pygcgopt:

pygcgopt: Python interface and modeling environment for GCG
===========================================================

Description
-----------

Python interface and modeling environment for GCG

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/PyGCGOpt/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_gcg`
- :ref:`spkg_pyscipopt`

Version Information
-------------------

package-version.txt::

    1.0.0b0

version_requirements.txt::

    PyGCGOpt

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install PyGCGOpt

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i pygcgopt


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
